@@ -1,6 +1,7 @@
 from uuid import uuid4
 
 from sqlalchemy import Column, DateTime, ForeignKey, Integer, String
+from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.sql.functions import func
 
 
@@ -12,10 +13,13 @@ class AuthenticateModel:
     id = Column(Integer, primary_key=True, autoincrement=True)
     token = Column(String, nullable=False, default=uuid4)
     refresh_token = Column(String, nullable=False, default=uuid4)
-    user_id = Column(Integer, ForeignKey('users.id'), nullable=True)
     expiry_date = Column(DateTime, nullable=True, default=func.now())
     refresh_expiry_time = Column(DateTime, nullable=True, default=func.now())
 
+    @declared_attr
+    def user_id(cls):
+        return Column(Integer, ForeignKey('user.id'), nullable=True)
+
     def __repr__(self):
         return f'<AuthToken: {self.user_id}'
 
